@@ -1,21 +1,21 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2011  Alibaba Cloud Computing
-# 
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
-# 
+#
 import random
 import threading
 import time
@@ -43,6 +43,7 @@ class Job(object):
                           ('InventorySizeInBytes', 'inventory_size', 0),
                           ('JobDescription', 'description', None),
                           ('JobId', 'id', None),
+                          ('RetrievalByteRange', 'job_range', None),
                           ('StatusCode', 'status_code', None),
                           ('StatusMessage', 'status_message', None))
 
@@ -61,6 +62,13 @@ class Job(object):
     def _is_multipart(self):
         return '-' in self.etag
 
+    def _parse_job_range(self):
+        return tuple([int(v) for v in self.job_range.split('-')])
+
+    def _is_complete_download(self):
+        byte_range = self._parse_job_range()
+        return byte_range == (0, self.archive_size - 1)
+
     def _update(self, response):
         for response_name, attr_name, default in self.ResponseDataParser:
             value = response.get(response_name)
@@ -68,12 +76,13 @@ class Job(object):
 
         self.parts = OrderedDict()
         if self.archive_size > 0:
+            size = range_size(self._parse_job_range())
             if self._is_multipart():
                 _, part_size = self._parse_etag()
-                for byte_range in calc_ranges(part_size, self.archive_size):
+                for byte_range in calc_ranges(part_size, size):
                     self.parts[byte_range] = None
             else:
-                self.parts[(0, self.archive_size - 1)] = None
+                self.parts[(0, size - 1)] = None
 
     def update_status(self):
         response = self.vault.api.describe_job(self.vault.id, self.id)
@@ -191,17 +200,20 @@ class Job(object):
                 download_part, [byte_range for byte_range, md5sum in self.parts.items() if md5sum is None])
 
             size = self.size_completed
-            if size != self.archive_size:
+            size_total = range_size(self._parse_job_range())
+            if size != size_total:
                 raise DownloadArchiveError(
-                    'Incomplete download: %d / %d' % (size, self.archive_size))
+                    'Incomplete download: %d / %d' % (size, size_total))
 
-            md5sum_list = [md5sum for _, md5sum in self.parts.items()]
-            md5sum_actual = compute_combine_md5(md5sum_list) \
-                if self._is_multipart() else md5sum_list[0]
-            if md5sum_actual != md5sum_comp:
-                raise HashDoesNotMatchError(
-                    'MD5 not match: %s / %s (actual)' % (md5sum_comp, md5sum_actual))
-            elif os.path.exists(log_file):
+            if self._is_complete_download():
+                md5sum_list = [md5sum for _, md5sum in self.parts.items()]
+                md5sum_actual = compute_combine_md5(md5sum_list) \
+                    if self._is_multipart() else md5sum_list[0]
+                if md5sum_actual != md5sum_comp:
+                    raise HashDoesNotMatchError(
+                        'MD5 not match: %s / %s (actual)' % (md5sum_comp, md5sum_actual))
+
+            if os.path.exists(log_file):
                 os.remove(log_file)
 
         print time.ctime() + ' Download finish.'
