@@ -94,6 +94,11 @@ class Uploader(object):
         for parts in result['Parts']:
             byte_range = self.parse_range_from_str(parts['RangeInBytes'])
             self.parts[byte_range] = parts['ContentEtag']
+            md5sum = compute_md5_from_file(
+                self.file_path, offset=byte_range[0], size=range_size(byte_range))
+            if md5sum != self.parts[byte_range]:
+                raise HashDoesNotMatchError('Hash does not match for %d-%d: %s, which %s excepted' % (
+                    byte_range[0], byte_range[1], md5sum, self.parts[byte_range]))
 
         return self.start()
 
