@@ -1,21 +1,21 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2011  Alibaba Cloud Computing
-# 
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
-# 
+#
 import mmap
 import os
 
@@ -139,9 +139,10 @@ class Vault(object):
         response = self.api.describe_job(self.id, job_id)
         return Job(self, response)
 
-    def retrieve_archive(self, archive_id, desc=None):
+    def retrieve_archive(self, archive_id, desc=None, byte_range=None):
         response = self.api.create_job(
-            self.id, 'archive-retrieval', archive_id=archive_id, desc=desc)
+            self.id, 'archive-retrieval', archive_id=archive_id, desc=desc,
+            byte_range='%d-%d' % byte_range if byte_range is not None else None)
         return self.get_job(response['x-oas-job-id'])
 
     def retrieve_inventory(self, desc=None):
