@@ -310,7 +310,19 @@ class OASCMD(object):
         job_type = args[2]
         archive_id = options.archive_id
         desc = options.desc
-        res = self.api.create_job(vault_id, job_type, archive_id, desc)
+
+        start = options.start
+        end = options.end
+        byte_range = None
+        if start is not None and end is not None:
+            byte_range = '%s-%s' % (start, end)
+        elif start is None and end is None:
+            byte_range = None
+        else:
+            print 'Error: both start and end should be set'
+            sys.exit(1)
+        
+        res = self.api.create_job(vault_id, job_type, archive_id, desc, byte_range)
         check_response(res)
         job_id = res.getheader('x-oas-job-id')
         print 'Job ID: %s' % job_id
@@ -324,6 +336,7 @@ class OASCMD(object):
         res = self.api.get_jobdesc(vault_id, job_id)
         check_response(res)
         rjson = json.loads(res.read(), 'UTF8')
+
         print 'JobId: %s' % rjson['JobId']
         print 'Action: %s' % rjson['Action']
         print 'StatusCode: %s' % rjson['StatusCode']
@@ -331,6 +344,7 @@ class OASCMD(object):
         print 'ArchiveId: %s' % rjson['ArchiveId']
         print 'ArchiveSizeInBytes: %s' % rjson['ArchiveSizeInBytes']
         print 'ArchiveContentEtag: %s' % rjson['ArchiveContentEtag']
+        print 'RetrievalByteRange: %s' % rjson['RetrievalByteRange']
         print 'Completed: %s' % rjson['Completed']
         print 'CompletionDate: %s' % convert_time_format(rjson['CompletionDate'])
         print 'InventorySizeInBytes: %s' % rjson['InventorySizeInBytes']
@@ -403,6 +417,7 @@ class OASCMD(object):
                 print 'ArchiveId: %s' % job['ArchiveId']
                 print 'ArchiveSizeInBytes: %s' % job['ArchiveSizeInBytes']
                 print 'ArchiveContentEtag: %s' % job['ArchiveContentEtag']
+                print 'RetrievalByteRange: %s' % job['RetrievalByteRange']
                 print 'Completed: %s' % job['Completed']
                 print 'CompletionDate: %s' % convert_time_format(job['CompletionDate'])
                 print 'InventorySizeInBytes: %s' % job['InventorySizeInBytes']
